# QNQ -- qnq's not quantization

- Program:
  - This tool is for TecArt algorithm team to quantize their custom neural network's pre-trained model.
- License:
  - GPL v3
- Operator supported
  - Convolution Layers
    - Conv1d, Conv2d, Conv3d
  - Pooling Layers
    - MaxPool
